@@ -299,12 +299,13 @@ test_that("Success run MultAdj with Case 1A", {
   expect_length(sim_summary, 4)
   expect_length(sim_summary$power, 2)
   expect_length(sim_summary$adj_power, 2)
-  expect_equal(sim_summary$power[1], 0.4, tolerance = 0.4)
-  expect_equal(sim_summary$power[2], 0.6, tolerance = 0.3)
-  expect_equal(sim_summary$adj_power[1], 0.3, tolerance = 0.3)
-  expect_equal(sim_summary$adj_power[2], 0.6, tolerance = 0.3)
-  expect_equal(sim_summary$disj_power, 0.6, tolerance = 0.3)
-  expect_equal(sim_summary$conj_power, 0.3, tolerance = 0.3)
+
+  expect_equal(unname(sim_summary$power[1]), 0.4, tolerance = 0.4)
+  expect_equal(unname(sim_summary$power[2]), 0.6, tolerance = 0.3)
+  expect_equal(unname(sim_summary$adj_power[1]), 0.3, tolerance = 0.3)
+  expect_equal(unname(sim_summary$adj_power[2]), 0.6, tolerance = 0.3)
+  expect_equal(unname(sim_summary$disj_power), 0.6, tolerance = 0.3)
+  expect_equal(unname(sim_summary$conj_power), 0.3, tolerance = 0.3)
 
   # Check for report generation
   GenerateReport(results, tempfile(fileext = ".docx"))
@@ -319,14 +320,14 @@ test_that("Success run MultAdj with Case 1B", {
   expect_length(sim_summary, 4)
   expect_length(sim_summary$power, 3)
   expect_length(sim_summary$adj_power, 3)
-  expect_equal(sim_summary$power[1], 0.4, tolerance = 0.4)
-  expect_equal(sim_summary$power[2], 0.8, tolerance = 0.3)
-  expect_equal(sim_summary$power[3], 1.0, tolerance = 0.3)
-  expect_equal(sim_summary$adj_power[1], 0.4, tolerance = 0.3)
-  expect_equal(sim_summary$adj_power[2], 0.8, tolerance = 0.3)
-  expect_equal(sim_summary$adj_power[3], 1.0, tolerance = 0.3)
-  expect_equal(sim_summary$disj_power, 1.0, tolerance = 0.3)
-  expect_equal(sim_summary$conj_power, 0.4, tolerance = 0.3)
+  expect_equal(unname(sim_summary$power[1]), 0.4, tolerance = 0.4)
+  expect_equal(unname(sim_summary$power[2]), 0.8, tolerance = 0.3)
+  expect_equal(unname(sim_summary$power[3]), 1.0, tolerance = 0.3)
+  expect_equal(unname(sim_summary$adj_power[1]), 0.4, tolerance = 0.3)
+  expect_equal(unname(sim_summary$adj_power[2]), 0.8, tolerance = 0.3)
+  expect_equal(unname(sim_summary$adj_power[3]), 1.0, tolerance = 0.3)
+  expect_equal(unname(sim_summary$disj_power), 1.0, tolerance = 0.3)
+  expect_equal(unname(sim_summary$conj_power), 0.4, tolerance = 0.3)
 
   # Check for report generation
   GenerateReport(results, tempfile(fileext = ".docx"))
@@ -340,9 +341,9 @@ test_that("Success run MultAdj with Case 2A", {
   sim_summary = results$sim_summary
   expect_length(sim_summary, 2)
   expect_length(sim_summary$power, 2)
-  expect_equal(sim_summary$power[1], 0.4, tolerance = 0.4)
-  expect_equal(sim_summary$power[2], 0.6, tolerance = 0.4)
-  expect_equal(sim_summary$adj_power, 0.7, tolerance = 0.3)
+  expect_equal(unname(sim_summary$power[1]), 0.4, tolerance = 0.4)
+  expect_equal(unname(sim_summary$power[2]), 0.6, tolerance = 0.4)
+  expect_equal(unname(sim_summary$adj_power), 0.7, tolerance = 0.3)
 
   # Check for report generation
   GenerateReport(results, tempfile(fileext = ".docx"))
@@ -357,14 +358,14 @@ test_that("Success run MultAdj with Case 2B", {
   expect_length(sim_summary, 4)
   expect_length(sim_summary$power, 3)
   expect_length(sim_summary$adj_power, 3)
-  expect_equal(sim_summary$power[1], 0.7, tolerance = 0.4)
-  expect_equal(sim_summary$power[2], 0.9, tolerance = 0.3)
-  expect_equal(sim_summary$power[3], 0.9, tolerance = 0.3)
-  expect_equal(sim_summary$adj_power[1], 0.7, tolerance = 0.3)
-  expect_equal(sim_summary$adj_power[2], 0.9, tolerance = 0.3)
-  expect_equal(sim_summary$adj_power[3], 0.9, tolerance = 0.3)
-  expect_equal(sim_summary$disj_power, 1, tolerance = 0.3)
-  expect_equal(sim_summary$conj_power, 0.6, tolerance = 0.4)
+  expect_equal(unname(sim_summary$power[1]), 0.7, tolerance = 0.4)
+  expect_equal(unname(sim_summary$power[2]), 0.9, tolerance = 0.3)
+  expect_equal(unname(sim_summary$power[3]), 0.9, tolerance = 0.3)
+  expect_equal(unname(sim_summary$adj_power[1]), 0.7, tolerance = 0.3)
+  expect_equal(unname(sim_summary$adj_power[2]), 0.9, tolerance = 0.3)
+  expect_equal(unname(sim_summary$adj_power[3]), 0.9, tolerance = 0.3)
+  expect_equal(unname(sim_summary$disj_power), 1, tolerance = 0.3)
+  expect_equal(unname(sim_summary$conj_power), 0.6, tolerance = 0.4)
 
   # Check for report generation
   GenerateReport(results, tempfile(fileext = ".docx"))
